Description: Use GraphicsMagick instead of ImageMagick.
Author: Jakub Wilk <jwilk@debian.org>
--- a/cuneiform_src/cli/cuneiform-cli.cpp
+++ b/cuneiform_src/cli/cuneiform-cli.cpp
@@ -341,6 +341,10 @@
     Magick::InitializeMagick("");
 #endif
 
+#ifdef USE_MAGICK
+    Magick::InitializeMagick("");
+#endif
+
     dib = read_file(infilename);
     if(!dib) // Error msg is already printed so just get out.
         return 1;
--- a/cuneiform_src/CMakeLists.txt
+++ b/cuneiform_src/CMakeLists.txt
@@ -34,15 +34,16 @@
 
 add_definitions(-D_USE_RVERLINE_)
 
-find_package(ImageMagick COMPONENTS Magick++)
-if(ImageMagick_Magick++_FOUND)
+include(FindPkgConfig)
+pkg_check_modules(GraphicsMagick QUIET GraphicsMagick++)
+if(GraphicsMagick_FOUND)
     set(USE_MAGICK TRUE)
-    include_directories(${ImageMagick_Magick++_INCLUDE_DIR})
-    message(STATUS "ImageMagick++ found at ${ImageMagick_Magick++_INCLUDE_DIR}.")
-    set(cli_ext_libs ${ImageMagick_Magick++_LIBRARY})
+    include_directories(${GraphicsMagick_INCLUDE_DIRS})
+    message(STATUS "GraphicsMagick++ found at ${GraphicsMagick_INCLUDE_DIRS}.")
+    set(cli_ext_libs ${GraphicsMagick_LIBRARIES})
 else()
     set(USE_MAGICK FALSE)
-    message(STATUS "ImageMagick++ not found. Only uncompressed BMP images supported.")
+    message(STATUS "GraphicsMagick++ not found. Only uncompressed BMP images supported.")
 endif()
 
 configure_file(${CMAKE_CURRENT_SOURCE_DIR}/Kern/include/config.h.in ${CMAKE_CURRENT_BINARY_DIR}/Kern/include/config.h)
